searchData={"items":[{"type":"module","title":"SparklineSvg","doc":"SparklineSvg is a library to generate SVG sparkline charts.\n\nA [sparkline](https://en.wikipedia.org/wiki/Sparkline) is a small, simple chart that is drawn\nwithout axes or coordinates. It presents the general shape of the variation of a dataset at a\nglance.\n\nSparklineSvg allows you to create a sparkline chart from various data shapes and show the dots,\nthe line, and the area under the line. You can also add markers to the chart to highlight\nspecific spots. You can also show common reference lines.\n\n## Usage example\n\n``` elixir\n# Datapoints and general options\ndatapoints = [1, 3, 2, 2, 5]\noptions = [width: 200, height: 40]\n\n# A very simple line chart\nsparkline = SparklineSvg.new(datapoints, options)\n\n# Display what you want\nline_options = [width: 0.3, color: \"green\"]\nsparkline = SparklineSvg.show_line(sparkline, line_options)\n\n# Render the chart to an SVG string\n{:ok, svg} = SparklineSvg.to_svg(sparkline) # or\nsvg = SparklineSvg.to_svg!(sparkline)\n```","ref":"SparklineSvg.html"},{"type":"module","title":"Datapoints - SparklineSvg","doc":"Datapoints are the values that will be used to draw the chart. They can be:\n- A **list of numbers**, where each number is a value for the `y` axis. The `x` axis will be the\n  index of the number in the list.\n- A **list of tuples** with two values. The first value is the `x` axis and the second value is\n  the `y` axis. The `x` value can be a `number`, a `DateTime`, a `Date`, a `Time`, or a\n  `NaiveDateTime`. The `y` value must be a `number`.\n\nAll values in the list must be of the same type.\n\n<!-- tabs-open -->\n#","ref":"SparklineSvg.html#module-datapoints"},{"type":"module","title":"Simple datapoints - SparklineSvg","doc":"``` elixir\n# Number datapoints\ndatapoints = [1, 2, 3]\ndatapoints = [1.1, 1.2, 1.3]\n\n# Datapoints with DateTime\ndatapoints = [~U[2021-01-01 00:00:00Z], ~U[2021-01-02 00:00:00Z], ~U[2021-01-03 00:00:00Z]]\n\n# Datapoints with Date\ndatapoints = [~D[2021-01-01], ~D[2021-01-02], ~D[2021-01-03]]\n\n# Datapoints with Time\ndatapoints = [~T[00:01:00], ~T[00:02:00], ~T[00:03:00]]\n\n# Datapoints with NaiveDateTime\ndatapoints = [~N[2021-01-01 00:00:00], ~N[2021-01-02 00:00:00], ~N[2021-01-03 00:00:00]]\n```\n\n#","ref":"SparklineSvg.html#module-simple-datapoints"},{"type":"module","title":"Tuple-based datapoints - SparklineSvg","doc":"``` elixir\n# Datapoints\ndatapoints = [{1, 1}, {2, 2}, {3, 3}]\ndatapoints = [{1.1, 1}, {1.2, 2}, {1.3, 3}]\n\n# Datapoints with DateTime\ndatapoints = [\n  {~U[2021-01-01 00:00:00Z], 1},\n  {~U[2021-01-02 00:00:00Z], 2},\n  {~U[2021-01-03 00:00:00Z], 3}\n]\n\n# Datapoints with Date\ndatapoints = [{~D[2021-01-01], 1}, {~D[2021-01-02], 2}, {~D[2021-01-03], 3}]\n\n# Datapoints with Time\ndatapoints = [{~T[00:01:00], 1}, {~T[00:02:00], 2}, {~T[00:03:00], 3}]\n\n# Datapoints with NaiveDateTime\ndatapoints = [\n  {~N[2021-01-01 00:00:00], 1},\n  {~N[2021-01-02 00:00:00], 2},\n  {~N[2021-01-03 00:00:00], 3}\n]\n```\n<!-- tabs-close -->","ref":"SparklineSvg.html#module-tuple-based-datapoints"},{"type":"module","title":"Markers - SparklineSvg","doc":"Markers are used to highlight specific spots on the chart. They differ from the datapoints and\ntherefore are set separately from it. You can add as many markers as you want to a chart.\n\nThere are two types of markers:\n- A single marker that will be rendered as a vertical line.\n- A range marker that will be rendered as a rectangle.\n\nMarkers are not used to calculate the boundaries of the chart. If a marker is set outside the\nrange of the chart, it will be rendered but won't be visible.\n\nWe always set the `x` value of the marker (position on the x axis). The marker must be of the\nsame type as the `x` axis of the chart.\n\n<!-- tabs-open -->\n#","ref":"SparklineSvg.html#module-markers"},{"type":"module","title":"Single marker - SparklineSvg","doc":"``` elixir\nsvg =\n  datapoints\n  |> SparklineSvg.new()\n  |> SparklineSvg.show_line()\n  |> SparklineSvg.add_marker(2)\n  |> SparklineSvg.add_marker([3, 4])\n  |> SparklineSvg.to_svg!()\n```\n\n#","ref":"SparklineSvg.html#module-single-marker"},{"type":"module","title":"Range marker - SparklineSvg","doc":"``` elixir\nsvg =\n  datapoints\n  |> SparklineSvg.new()\n  |> SparklineSvg.show_line()\n  |> SparklineSvg.add_marker({1, 2})\n  |> SparklineSvg.add_marker([{3, 4}, {5, 6}])\n  |> SparklineSvg.to_svg!()\n```\n<!-- tabs-close -->","ref":"SparklineSvg.html#module-range-marker"},{"type":"module","title":"Reference lines - SparklineSvg","doc":"Reference lines are used to show common reference line on the chart. You can add as many\nreference lines as you want. Reference lines are displayed as horizontal lines that span the\nentire width of the chart.\n\nThere are four types of currently supported reference lines:\n- `:max` - show the maximum value of the chart.\n- `:min` - show the minimum value of the chart.\n- `:avg` - show the average value of the chart.\n- `:median` - show the median value of the chart.\n\n``` elixir\nsvg =\n  datapoints\n  |> SparklineSvg.new()\n  |> SparklineSvg.show_line()\n  |> SparklineSvg.show_ref_line(:max, color: \"red\")\n  |> SparklineSvg.to_svg!()\n```","ref":"SparklineSvg.html#module-reference-lines"},{"type":"module","title":"Customization - SparklineSvg","doc":"SparklineSvg allows you to customize the chart showing or hiding the dots, the line, and the area\nunder the line as well as markers and reference lines.\n\nThere are two ways to customize the chart:\n- Using the options like `:color` or `:width`.\n- Using the CSS classes option to give classes to SVG elements and then using CSS to style them.\n\n<!-- tabs-open -->\n#","ref":"SparklineSvg.html#module-customization"},{"type":"module","title":"Options - SparklineSvg","doc":"``` elixir\nsvg =\n  datapoints\n  |> SparklineSvg.new(width: 100, height: 40, padding: 0.5, placeholder: \"No data\")\n  |> SparklineSvg.show_dots(radius: 0.1, color: \"rgb(255, 255, 255)\")\n  |> SparklineSvg.show_line(width: 0.5, color: \"rgb(166, 218, 149)\")\n  |> SparklineSvg.show_area(color: \"rgba(166, 218, 149, 0.2)\")\n  |> SparklineSvg.add_marker(1, stroke_color: \"red\", stroke_width: 0.5)\n  |> SparklineSvg.show_ref_line(:max, width: 0.3, color: \"red\")\n  |> SparklineSvg.to_svg!()\n```\n\n#","ref":"SparklineSvg.html#module-options"},{"type":"module","title":"CSS classes - SparklineSvg","doc":"``` elixir\nsvg =\n  datapoints\n  |> SparklineSvg.new(width: 100, height: 40, padding: 0.5, placeholder: \"No data\", class: \"sparkline\")\n  |> SparklineSvg.show_dots(class: \"sparkline-dots\")\n  |> SparklineSvg.show_line(class: \"sparkline-line\")\n  |> SparklineSvg.show_area(class: \"sparkline-area\")\n  |> SparklineSvg.add_marker(1, class: \"sparkline-marker\")\n  |> SparklineSvg.show_ref_line(:max, class: \"sparkline-max-value\")\n  |> SparklineSvg.to_svg!()\n```\n\n#","ref":"SparklineSvg.html#module-css-classes"},{"type":"module","title":"Tailwind classes - SparklineSvg","doc":"``` elixir\nsvg =\n  datapoints\n  |> SparklineSvg.new(width: 100, height: 40, padding: 0.5, placeholder: \"No data\", class: \"bg-transparent\")\n  |> SparklineSvg.show_dots(class: \"fill-green\")\n  |> SparklineSvg.show_line(class: \"stroke-green stroke-[0.5px] fill-transparent\")\n  |> SparklineSvg.show_area(class: \"fill-green/10\")\n  |> SparklineSvg.add_marker(1, class: \"stroke-red stroke-[0.5px] fill-transparent\")\n  |> SparklineSvg.show_ref_line(:max, class: \"stroke-red stroke-[0.3px]\")\n  |> SparklineSvg.to_svg!()\n```\n<!-- tabs-close -->\n\nWhen using the CSS classes to style the chart, the other options like `:color` or `:width` will\nbe ignored. However, some options (`:width`, `:height`, `padding`, `smoothing`, and\n`placeholder`), are used internally to render the chart and are required in any case.\n\n#","ref":"SparklineSvg.html#module-tailwind-classes"},{"type":"module","title":"Available options - SparklineSvg","doc":"Use the following options to customize the chart:\n\n- `:width` - the width of the chart, defaults to `200`.\n- `:height` - the height of the chart, defaults to `50`.\n- `:padding` - the padding of the chart, defaults to `2`. Not targetable with CSS classes.\n  Padding has to be set to a value which `padding * 2 < width` and `padding * 2 < height`\n  otherwise a `:invalid_dimension` error will be raised.\n- `:smoothing` - the smoothing of the line (`0` = no smoothing, above `0.4` it becomes\n  unreadable), defaults to `0.15`. Not targetable with CSS classes.\n- `:placeholder` - a placeholder for an empty chart, defaults to `nil`. If set to `nil`, a chart\n  with no datapoints will be an empty SVG document. Alternatively, you can set it to a string to\n  display a message when the chart is empty. Not targetable with CSS classes.\n- `:class` - the value of the HTML class attribut of the chart, defaults to `nil`.\n- `:placeholder_class` - the value of the HTML class attribut of the placeholder, defaults to\n`nil`. It is the only way to style the placeholder.\n\n#","ref":"SparklineSvg.html#module-available-options"},{"type":"module","title":"Dots options - SparklineSvg","doc":"- `:radius` - the radius of the dots, defaults to `1`.\n- `:color` - the color of the dots, defaults to `\"black\"`.\n- `:class` - the value of the HTML class attribut of the dots, defaults to `nil`.\n\n#","ref":"SparklineSvg.html#module-dots-options"},{"type":"module","title":"Line options - SparklineSvg","doc":"- `:width` - the width of the line, defaults to `0.25`.\n- `:color` - the color of the line, defaults to `\"black\"`.\n- `:dasharray` - the value of the HTML stroke-dasharray attribut of the line, defaults to `\"\"`.\n  Valid dasharray values can be found [here](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/stroke-dasharray).\n- `:class` - the value of the HTML class attribut of the line, defaults to `nil`.\n\n#","ref":"SparklineSvg.html#module-line-options"},{"type":"module","title":"Area options - SparklineSvg","doc":"- `:color` - the color of the area under the line, defaults to `\"rgba(0, 0, 0, 0.1)\"`.\n- `:class` - the value of the HTML class attribut of the area, defaults to `nil`.\n\n#","ref":"SparklineSvg.html#module-area-options"},{"type":"module","title":"Marker options - SparklineSvg","doc":"- `:stroke_width` - the stroke width of the marker, defaults to `0.25`.\n- `:stroke_color` - the stroke color of the marker, defaults to `\"red\"`.\n- `:stroke_dasharray` - the value of the HTML stroke-dasharray attribut of the marker, defaults\n  to `\"\"`. Valid dasharray values can be found\n  [here](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/stroke-dasharray).\n- `:fill_color` - the fill color of an area marker, defaults to `\"rgba(255, 0, 0, 0.1)\"`.\n- `:class` - the value of the HTML class attribut of the marker, defaults to `nil`.\n\n#","ref":"SparklineSvg.html#module-marker-options"},{"type":"module","title":"Reference line options - SparklineSvg","doc":"- `:width` - the width of the reference line, defaults to `0.25`.\n- `:color` - the color of the reference line, defaults to `\"rgba(0, 0, 0, 0.5)\"`.\n- `:dasharray` - the value of the HTML stroke-dasharray attribut of the reference line, defaults\n  to `\"\"`. Valid dasharray values can be found\n  [here](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/stroke-dasharray).\n- `:class` - the value of the HTML class attribut of the reference line, defaults to `nil`.","ref":"SparklineSvg.html#module-reference-line-options"},{"type":"function","title":"SparklineSvg.add_marker/3","doc":"Add one or many markers to a sparkline struct with the given options.\n\nWhen calling this function with a list of markers, the options will be applied to all the markers.\n\nIf you want to apply different options to different markers, you can call this function multiple\ntimes with a single marker and the desired options.\n\nMarkers are not used to calculate the boudaries of the chart. If you set a marker outside the range\nof the chart, it will be rendered but won't be visible.","ref":"SparklineSvg.html#add_marker/3"},{"type":"function","title":"Examples - SparklineSvg.add_marker/3","doc":"iex> chart = SparklineSvg.new([1, 3]) |> SparklineSvg.add_marker(2)\n    iex> SparklineSvg.to_svg!(chart)\n    ~S'   '\n\n    iex> chart = SparklineSvg.new([1, 3]) |> SparklineSvg.add_marker({2.1, 2.4})\n    iex> SparklineSvg.to_svg!(chart)\n    ~S'   '\n\n    iex> chart = SparklineSvg.new([1, 3]) |> SparklineSvg.add_marker(2, stroke_color: \"rgba(0, 255, 0, 0.2)\")\n    iex> SparklineSvg.to_svg!(chart)\n    ~S'   '","ref":"SparklineSvg.html#add_marker/3-examples"},{"type":"function","title":"SparklineSvg.as_data_uri/1","doc":"Convert a svg string into a Base64 string to be used, for example, as a background-image.\n\nNote that using SVG as a background-image has some limitations. For example, CSS Selectors in a\nhost document cannot query an SVG document that is embedded as an external resource as opposed to\nbeing inlined with the host document markup.","ref":"SparklineSvg.html#as_data_uri/1"},{"type":"function","title":"Examples - SparklineSvg.as_data_uri/1","doc":"iex> svg = SparklineSvg.new([1, 2]) |> SparklineSvg.to_svg!()\n    iex> SparklineSvg.as_data_uri(svg)\n    \"data:image/svg+xml;base64,PHN2ZyB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB2aWV3Qm94PSIwIDAgMjAwIDUwIiB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPjwvc3ZnPg==\"","ref":"SparklineSvg.html#as_data_uri/1-examples"},{"type":"function","title":"SparklineSvg.new/2","doc":"Create a new sparkline struct with the given datapoints and options.\n\nIf neither `SparklineSvg.show_dots/2`, `SparklineSvg.show_line/2`, nor `SparklineSvg.show_area/2`\nare called, the rendered chart will be an empty SVG document.","ref":"SparklineSvg.html#new/2"},{"type":"function","title":"Examples - SparklineSvg.new/2","doc":"iex> chart = SparklineSvg.new([1, 2])\n    iex> SparklineSvg.to_svg!(chart)\n    ~S'  '\n\n    iex> chart = SparklineSvg.new([1, 2], width: 240, height: 80)\n    iex> SparklineSvg.to_svg!(chart)\n    ~S'  '","ref":"SparklineSvg.html#new/2-examples"},{"type":"function","title":"SparklineSvg.show_area/2","doc":"Take a sparkline struct and return a new sparkline struct with the given area options.\n\nCalling this function multiple times will override the previous area options. If no options are\ngiven, the area will be shown with the default options.","ref":"SparklineSvg.html#show_area/2"},{"type":"function","title":"Examples - SparklineSvg.show_area/2","doc":"iex> chart = SparklineSvg.new([1, 2]) |> SparklineSvg.show_area()\n    iex> SparklineSvg.to_svg!(chart)\n    ~S'   '\n\n    iex> chart = SparklineSvg.new([1, 2]) |> SparklineSvg.show_area(color: \"rgba(0, 255, 255, 0.2)\")\n    iex> SparklineSvg.to_svg!(chart)\n    ~S'   '","ref":"SparklineSvg.html#show_area/2-examples"},{"type":"function","title":"SparklineSvg.show_dots/2","doc":"Take a sparkline struct and return a new sparkline struct with the given dots options.\n\nCalling this function multiple times will override the previous dots options. If no options are\ngiven, the dots will be shown with the default options.","ref":"SparklineSvg.html#show_dots/2"},{"type":"function","title":"Examples - SparklineSvg.show_dots/2","doc":"iex> chart = SparklineSvg.new([1, 2]) |> SparklineSvg.show_dots()\n    iex> SparklineSvg.to_svg!(chart)\n    ~S'    '\n\n    iex> chart = SparklineSvg.new([1, 2]) |> SparklineSvg.show_dots(radius: 0.5, color: \"red\")\n    iex> SparklineSvg.to_svg!(chart)\n    ~S'    '","ref":"SparklineSvg.html#show_dots/2-examples"},{"type":"function","title":"SparklineSvg.show_line/2","doc":"Take a sparkline struct and return a new sparkline struct with the given line options.\n\nCalling this function multiple times will override the previous line options. If no options are\ngiven, the line will be shown with the default options.","ref":"SparklineSvg.html#show_line/2"},{"type":"function","title":"Examples - SparklineSvg.show_line/2","doc":"iex> chart = SparklineSvg.new([1, 2]) |> SparklineSvg.show_line()\n    iex> SparklineSvg.to_svg!(chart)\n    ~S'   '\n\n    iex> chart = SparklineSvg.new([1, 2]) |> SparklineSvg.show_line(width: 0.1, color: \"green\")\n    iex> SparklineSvg.to_svg!(chart)\n    ~S'   '","ref":"SparklineSvg.html#show_line/2-examples"},{"type":"function","title":"SparklineSvg.show_ref_line/3","doc":"Add one reference line to a sparkline struct with the given options.\n\nAvailable reference lines are `:max`, `:min`, `:avg`, and `:median`.\n\nReference lines on an empty chart won't be rendered.","ref":"SparklineSvg.html#show_ref_line/3"},{"type":"function","title":"Examples - SparklineSvg.show_ref_line/3","doc":"iex> chart = SparklineSvg.new([1, 2]) |> SparklineSvg.show_ref_line(:max)\n    iex> SparklineSvg.to_svg!(chart)\n    ~S'   '\n\n    iex> chart = SparklineSvg.new([1, 2]) |> SparklineSvg.show_ref_line(:avg, color: \"red\")\n    iex> SparklineSvg.to_svg!(chart)\n    ~S'   '","ref":"SparklineSvg.html#show_ref_line/3-examples"},{"type":"function","title":"SparklineSvg.to_svg/1","doc":"Return a valid SVG document from a sparkline struct.","ref":"SparklineSvg.html#to_svg/1"},{"type":"function","title":"Examples - SparklineSvg.to_svg/1","doc":"iex> SparklineSvg.new([1, 2]) |> SparklineSvg.to_svg()\n    {:ok, ~S'  '}\n\n    iex> SparklineSvg.new([1, 2], width: 10, padding: 10) |> SparklineSvg.to_svg()\n    {:error, :invalid_dimension}","ref":"SparklineSvg.html#to_svg/1-examples"},{"type":"function","title":"SparklineSvg.to_svg!/1","doc":"Return a valid SVG document from a sparkline struct.","ref":"SparklineSvg.html#to_svg!/1"},{"type":"function","title":"Examples - SparklineSvg.to_svg!/1","doc":"iex> SparklineSvg.new([1, 2]) |> SparklineSvg.to_svg!()\n    ~S'  '\n\n    iex> SparklineSvg.new([1, 2], width: 10, padding: 10) |> SparklineSvg.to_svg!()\n    ** (SparklineSvg.Error) invalid_dimension","ref":"SparklineSvg.html#to_svg!/1-examples"},{"type":"type","title":"SparklineSvg.area_options/0","doc":"Keyword list of options for the area under the line of the chart.","ref":"SparklineSvg.html#t:area_options/0"},{"type":"type","title":"SparklineSvg.datapoint/0","doc":"A datapoint for the chart.","ref":"SparklineSvg.html#t:datapoint/0"},{"type":"type","title":"SparklineSvg.datapoints/0","doc":"A list of datapoint.\n\nIt can be a list of various types of datapoints, but all the datapoints in the list must be of the\nsame type.","ref":"SparklineSvg.html#t:datapoints/0"},{"type":"type","title":"SparklineSvg.dots_options/0","doc":"Keyword list of options for the dots of the chart.","ref":"SparklineSvg.html#t:dots_options/0"},{"type":"type","title":"SparklineSvg.line_options/0","doc":"Keyword list of options for the line of the chart.","ref":"SparklineSvg.html#t:line_options/0"},{"type":"type","title":"SparklineSvg.marker/0","doc":"A value or a two-tuple value for the x axis of the chart.","ref":"SparklineSvg.html#t:marker/0"},{"type":"type","title":"SparklineSvg.marker_options/0","doc":"Keyword list of options for a marker of the chart.","ref":"SparklineSvg.html#t:marker_options/0"},{"type":"type","title":"SparklineSvg.markers/0","doc":"A list of values or a list of two-tuple values for the x axis of the chart.","ref":"SparklineSvg.html#t:markers/0"},{"type":"type","title":"SparklineSvg.options/0","doc":"Keyword list of options for the chart.","ref":"SparklineSvg.html#t:options/0"},{"type":"type","title":"SparklineSvg.ref_line/0","doc":"The type of reference line.","ref":"SparklineSvg.html#t:ref_line/0"},{"type":"type","title":"SparklineSvg.ref_line_options/0","doc":"Keyword list of options for a reference line.","ref":"SparklineSvg.html#t:ref_line_options/0"},{"type":"type","title":"SparklineSvg.x/0","doc":"A value for the x axis of the chart.","ref":"SparklineSvg.html#t:x/0"},{"type":"type","title":"SparklineSvg.y/0","doc":"A number value for the y axis of the chart.","ref":"SparklineSvg.html#t:y/0"},{"type":"exception","title":"SparklineSvg.Error","doc":"An exception raised when datapoints, markers, or options are invalid.\n\n`SparklineSvg.Error` exceptions have a single field, :message (a String.t/0), which is public.","ref":"SparklineSvg.Error.html"},{"type":"extras","title":"About","doc":"# Sparkline SVG\n\n[![Module Version](https://img.shields.io/hexpm/v/sparkline_svg.svg)](https://hex.pm/packages/sparkline_svg)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/sparkline_svg/)\n[![License](https://img.shields.io/hexpm/l/sparkline_svg.svg)](https://github.com/abdelaz3r/sparkline_svg/blob/main/LICENSE)\n[![Last Updated](https://img.shields.io/github/last-commit/abdelaz3r/sparkline_svg.svg)](https://github.com/abdelaz3r/sparkline_svg/commits/main)\n\n<!--[![Total Download](https://img.shields.io/hexpm/dt/sparkline_svg.svg)](https://hex.pm/packages/sparkline_svg) -->\n\n**Sparkline SVG** is simple yet customizable, zero-dependency, Elixir library to generate SVG\nsparkline charts.\n\n[Online documentation](https://hexdocs.pm/sparkline_svg).","ref":"readme.html"},{"type":"extras","title":"Overview - About","doc":"A [sparkline](https://en.wikipedia.org/wiki/Sparkline) is a small, simple chart that is drawn\nwithout axes or coordinates. It presents the general shape of the variation of a dataset at a\nglance.\n\nSparkline SVG allows you to create a sparkline chart from various data shapes and show the dots,\nthe line, and the area under the line. You can also add markers to the chart to highlight\nspecific spots as well as show common reference lines.\n\nThis library follow the Unix philosophy: Make each program do one thing well. It only generates SVG\nsparkline charts. The library is highly customizable and allows you to use CSS to style the chart \nas well as keyword options.\n\n#","ref":"readme.html#overview"},{"type":"extras","title":"Datapoints - About","doc":"Datapoints are the values that will be used to draw the chart. They can be:\n- A **list of numbers**, where each number is a value for the y axis.\n- A **list of tuples** with two values. The first value is the x axis and the second value is\n  the y axis.\n\n#","ref":"readme.html#datapoints"},{"type":"extras","title":"Markers - About","doc":"Markers are used to highlight specific spots on the chart. There are two types of markers:\n- A single marker that will be rendered as a vertical line.\n- A range marker that will be rendered as a rectangle.\n\n#","ref":"readme.html#markers"},{"type":"extras","title":"Reference lines - About","doc":"Reference lines are used to show common reference lines on the chart. There are four types of\ncurrently supported reference lines (`maximum`, `minimum`, `average`, and `median`) that will\nbe rendered as horizontal lines.\n\n#","ref":"readme.html#reference-lines"},{"type":"extras","title":"Customization - About","doc":"Sparkline SVG allows you to customize the chart showing or hiding the dots, the line, and the area\nunder the line. There are two ways to customize the chart:\n- Using the options like color or width.\n- Using the CSS classes option to give classes to SVG elements and then using CSS to style them.\n\n#","ref":"readme.html#customization"},{"type":"extras","title":"Usage example - About","doc":"``` elixir\n# Datapoints and general options\ndatapoints = [1, 3, 2, 2, 5]\noptions = [width: 100, height: 40]\n\n# A very simple line chart\nsparkline = SparklineSvg.new(datapoints, options)\n\n# Display what you want\nline_options = [width: 0.25, color: \"black\"]\nsparkline = SparklineSvg.show_line(sparkline, line_options)\n\n# Render the chart to an SVG string\n{:ok, svg} = SparklineSvg.to_svg(sparkline)\n```\n\nFor more usage examples, visit the [documentation](https://hexdocs.pm/sparkline_svg).","ref":"readme.html#usage-example"},{"type":"extras","title":"Installation - About","doc":"The package can be installed by adding `:sparkline_svg` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:sparkline_svg, \"~> 0.2.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Status - About","doc":"This library is currently under active development and it’s API is likely to change.","ref":"readme.html#status"},{"type":"extras","title":"Examples - About","doc":"#","ref":"readme.html#examples"},{"type":"extras","title":"Light sparkline - About","doc":"A cyan sparkline with a line, area, and markers\n\n``` elixir\n# Data source\ndata = [4, 4, 6, 3, 2, 1, 3, 5, 7, 7, 7, 6, 9, 11, 11, 5, 7, 6, 9, 19, 19, 20, 21, 20, 17, 20, 19, 17]\n\n# Arbitrary marker and marker area\nmarker = 25\nmarker_area = {10, 15}\n\ndata\n|> SparklineSvg.new(smoothing: 0.05)\n|> SparklineSvg.show_line(color: \"rgba(6, 182, 212, 0.5)\", width: 0.4)\n|> SparklineSvg.show_area(color: \"rgba(6, 182, 212, 0.2)\")\n|> SparklineSvg.add_marker(marker, stroke_color: \"rgba(236, 72, 153, 0.8)\", stroke_width: 0.4)\n|> SparklineSvg.add_marker(marker_area, stroke_color: \"rgba(236, 72, 153, 0.4)\", stroke_width: 0.4, fill_color: \"rgba(236, 72, 153, 0.2)\")\n|> SparklineSvg.to_svg!()\n```\n\n![A cyan sparkline with a line, area, and markers](https://raw.githubusercontent.com/abdelaz3r/sparkline_svg/main/documents/assets/light-sparkline-example.png)\n\n#","ref":"readme.html#light-sparkline"},{"type":"extras","title":"Dark sparkline - About","doc":"A green sparkline, on dark background, with a line, and area\n\n``` elixir\n# Data source\ndata = [4, 4, 6, 3, 2, 1, 3, 5, 7, 7, 7, 6, 9, 11, 11, 5, 7, 6, 9, 19, 19, 20, 21, 20, 17, 20, 19, 17]\n\ndata\n|> SparklineSvg.new(width: 200, height: 30, smoothing: 0)\n|> SparklineSvg.show_line(color: \"rgba(40, 255, 118, 0.8)\", width: 0.4)\n|> SparklineSvg.show_area(color: \"rgba(40, 255, 118, 0.4)\")\n|> SparklineSvg.to_svg!()\n```\n\n![A green sparkline, on dark background, with a line, and area](https://raw.githubusercontent.com/abdelaz3r/sparkline_svg/main/documents/assets/dark-sparkline-example.png)","ref":"readme.html#dark-sparkline"},{"type":"extras","title":"Examples","doc":"These examples are meant to be used directly in your code. You can copy and paste them in your\nproject and they will work out of the box. The colors had been chosen following the [tailwind\ncolor palette](https://tailwindcss.com/docs/customizing-colors). Each example is shown in light and\ndark mode.\n\nAll these examples are set with these 3 variables:\n\n``` elixir\n# Data source\ndata = [4, 4, 6, 3, 2, 1, 3, 5, 7, 7, 7, 6, 9, 11, 11, 5, 7, 6, 9, 19, 19, 20, 21, 20, 17, 20, 19, 17]\n\n# Arbitrary marker and marker area\nmarker = 25\nmarker_area = {10, 15}\n```","ref":"examples.html"},{"type":"extras","title":"Cyan theme - Examples","doc":"<!-- tabs-open -->\n\n#","ref":"examples.html#cyan-theme"},{"type":"extras","title":"Light theme - Examples","doc":"``` elixir\ndata\n|> SparklineSvg.new(smoothing: 0.05, padding: 0)\n|> SparklineSvg.show_line(color: \"rgba(6, 182, 212, 0.5)\", width: 0.4)\n|> SparklineSvg.show_area(color: \"rgba(6, 182, 212, 0.2)\")\n|> SparklineSvg.add_marker(marker, stroke_color: \"rgba(236, 72, 153, 0.8)\", stroke_width: 0.4)\n|> SparklineSvg.add_marker(marker_area, stroke_color: \"rgba(236, 72, 153, 0.4)\", stroke_width: 0.4, fill_color: \"rgba(236, 72, 153, 0.2)\")\n|> SparklineSvg.to_svg!()\n```\n\n \n        \n \n\n#","ref":"examples.html#light-theme"},{"type":"extras","title":"Dark theme - Examples","doc":"``` elixir\ndata\n|> SparklineSvg.new(smoothing: 0.05, padding: 0)\n|> SparklineSvg.show_line(color: \"rgb(22, 197, 245)\", width: 0.4)\n|> SparklineSvg.show_area(color: \"rgba(22, 197, 245, 0.4)\")\n|> SparklineSvg.add_marker(marker, stroke_color: \"rgba(255, 68, 166, 0.6)\", stroke_width: 0.4)\n|> SparklineSvg.add_marker(marker_area, stroke_color: \"rgba(255, 68, 166, 0.4)\", stroke_width: 0.4, fill_color: \"rgba(255, 68, 166, 0.3)\")\n|> SparklineSvg.to_svg!()\n```\n\n \n        \n \n\n<!-- tabs-close -->","ref":"examples.html#dark-theme"},{"type":"extras","title":"Teal theme - Examples","doc":"<!-- tabs-open -->\n\n#","ref":"examples.html#teal-theme"},{"type":"extras","title":"Light theme - Examples","doc":"``` elixir\ndata\n|> SparklineSvg.new(smoothing: 0.05, padding: 0)\n|> SparklineSvg.show_line(color: \"rgba(13, 148, 136, 0.5)\", width: 0.4)\n|> SparklineSvg.show_area(color: \"rgba(13, 148, 136, 0.2)\")\n|> SparklineSvg.add_marker(marker, stroke_color: \"rgba(236, 72, 153, 0.8)\", stroke_width: 0.4)\n|> SparklineSvg.add_marker(marker_area, stroke_color: \"rgba(236, 72, 153, 0.4)\", stroke_width: 0.4, fill_color: \"rgba(236, 72, 153, 0.2)\")\n|> SparklineSvg.to_svg!()\n```\n\n \n        \n \n\n#","ref":"examples.html#light-theme"},{"type":"extras","title":"Dark theme - Examples","doc":"``` elixir\ndata\n|> SparklineSvg.new(smoothing: 0.05, padding: 0)\n|> SparklineSvg.show_line(color: \"rgb(23, 227, 209)\", width: 0.4)\n|> SparklineSvg.show_area(color: \"rgba(23, 227, 209, 0.4)\")\n|> SparklineSvg.add_marker(marker, stroke_color: \"rgba(255, 68, 166, 0.6)\", stroke_width: 0.4)\n|> SparklineSvg.add_marker(marker_area, stroke_color: \"rgba(255, 68, 166, 0.4)\", stroke_width: 0.4, fill_color: \"rgba(255, 68, 166, 0.3)\")\n|> SparklineSvg.to_svg!()\n```\n\n \n        \n \n\n<!-- tabs-close -->","ref":"examples.html#dark-theme"},{"type":"extras","title":"Indigo theme - Examples","doc":"<!-- tabs-open -->\n\n#","ref":"examples.html#indigo-theme"},{"type":"extras","title":"Light theme - Examples","doc":"``` elixir\ndata\n|> SparklineSvg.new(smoothing: 0.05, padding: 0)\n|> SparklineSvg.show_line(color: \"rgba(67, 56, 202, 0.5)\", width: 0.4)\n|> SparklineSvg.show_area(color: \"rgba(67, 56, 202, 0.2)\")\n|> SparklineSvg.add_marker(marker, stroke_color: \"rgba(236, 72, 153, 0.8)\", stroke_width: 0.4)\n|> SparklineSvg.add_marker(marker_area, stroke_color: \"rgba(236, 72, 153, 0.4)\", stroke_width: 0.4, fill_color: \"rgba(236, 72, 153, 0.2)\")\n|> SparklineSvg.to_svg!()\n```\n\n \n        \n \n\n#","ref":"examples.html#light-theme"},{"type":"extras","title":"Dark theme - Examples","doc":"``` elixir\ndata\n|> SparklineSvg.new(smoothing: 0.05, padding: 0)\n|> SparklineSvg.show_line(color: \"rgb(102, 89, 255)\", width: 0.4)\n|> SparklineSvg.show_area(color: \"rgba(102, 89, 255, 0.4)\")\n|> SparklineSvg.add_marker(marker, stroke_color: \"rgba(255, 68, 166, 0.6)\", stroke_width: 0.4)\n|> SparklineSvg.add_marker(marker_area, stroke_color: \"rgba(255, 68, 166, 0.4)\", stroke_width: 0.4, fill_color: \"rgba(255, 68, 166, 0.3)\")\n|> SparklineSvg.to_svg!()\n```\n\n \n        \n \n\n<!-- tabs-close -->","ref":"examples.html#dark-theme"},{"type":"extras","title":"Black & white theme - Examples","doc":"<!-- tabs-open -->\n\n#","ref":"examples.html#black-white-theme"},{"type":"extras","title":"Light theme - Examples","doc":"``` elixir\ndata\n|> SparklineSvg.new(smoothing: 0.05, padding: 0)\n|> SparklineSvg.show_line(color: \"rgb(0, 0, 0)\", width: 0.4)\n|> SparklineSvg.show_area(color: \"rgba(0, 0, 0, 0.9)\")\n|> SparklineSvg.add_marker(marker, stroke_color: \"rgb(243, 244, 246\", stroke_width: 0.4)\n|> SparklineSvg.add_marker(marker_area, stroke_color: \"rgba(243, 244, 246, 0.8)\", stroke_width: 0.4, fill_color: \"rgba(243, 244, 246, 0.1)\")\n|> SparklineSvg.to_svg!()\n```\n\n \n       \n \n\n#","ref":"examples.html#light-theme"},{"type":"extras","title":"Dark theme - Examples","doc":"``` elixir\ndata\n|> SparklineSvg.new(smoothing: 0.05, padding: 0)\n|> SparklineSvg.show_line(color: \"rgb(240, 240, 240)\", width: 0.4)\n|> SparklineSvg.show_area(color: \"rgba(240, 240, 240, 0.9)\")\n|> SparklineSvg.add_marker(marker, stroke_color: \"rgba(40, 40, 40, 0.9)\", stroke_width: 0.4)\n|> SparklineSvg.add_marker(marker_area, stroke_color: \"rgba(40, 40, 40, 0.8)\", stroke_width: 0.4, fill_color: \"rgba(40, 40, 40, 0.3)\")\n|> SparklineSvg.to_svg!()\n```\n\n \n       \n \n\n<!-- tabs-close -->","ref":"examples.html#dark-theme"},{"type":"extras","title":"Simple amber theme - Examples","doc":"<!-- tabs-open -->\n\n#","ref":"examples.html#simple-amber-theme"},{"type":"extras","title":"Light theme - Examples","doc":"``` elixir\ndata\n|> SparklineSvg.new(width: 200, height: 30, smoothing: 0, padding: 0)\n|> SparklineSvg.show_line(color: \"rgba(245, 158, 11, 0.5)\", width: 0.4)\n|> SparklineSvg.show_area(color: \"rgba(245, 158, 11, 0.2)\")\n|> SparklineSvg.add_marker(marker)\n|> SparklineSvg.add_marker(marker_area)\n|> SparklineSvg.to_svg!()\n```\n\n \n      \n \n\n#","ref":"examples.html#light-theme"},{"type":"extras","title":"Dark theme - Examples","doc":"``` elixir\ndata\n|> SparklineSvg.new(width: 200, height: 30, smoothing: 0, padding: 0)\n|> SparklineSvg.show_line(color: \"rgba(255, 165, 22, 0.8)\", width: 0.4)\n|> SparklineSvg.show_area(color: \"rgba(255, 165, 22, 0.4)\")\n|> SparklineSvg.add_marker(marker)\n|> SparklineSvg.add_marker(marker_area)\n|> SparklineSvg.to_svg!()\n```\n\n \n      \n \n\n<!-- tabs-close -->","ref":"examples.html#dark-theme"},{"type":"extras","title":"Simple green theme - Examples","doc":"<!-- tabs-open -->\n\n#","ref":"examples.html#simple-green-theme"},{"type":"extras","title":"Light theme - Examples","doc":"``` elixir\ndata\n|> SparklineSvg.new(width: 200, height: 30, smoothing: 0, padding: 0)\n|> SparklineSvg.show_line(color: \"rgba(34, 197, 94, 0.5)\", width: 0.4)\n|> SparklineSvg.show_area(color: \"rgba(34, 197, 94, 0.2)\")\n|> SparklineSvg.add_marker(marker)\n|> SparklineSvg.add_marker(marker_area)\n|> SparklineSvg.to_svg!()\n```\n\n \n      \n \n\n#","ref":"examples.html#light-theme"},{"type":"extras","title":"Dark theme - Examples","doc":"``` elixir\ndata\n|> SparklineSvg.new(width: 200, height: 30, smoothing: 0, padding: 0)\n|> SparklineSvg.show_line(color: \"rgba(40, 255, 118, 0.8)\", width: 0.4)\n|> SparklineSvg.show_area(color: \"rgba(40, 255, 118, 0.4)\")\n|> SparklineSvg.add_marker(marker)\n|> SparklineSvg.add_marker(marker_area)\n|> SparklineSvg.to_svg!()\n```\n\n \n      \n \n\n<!-- tabs-close -->","ref":"examples.html#dark-theme"},{"type":"extras","title":"Simple sky theme - Examples","doc":"<!-- tabs-open -->\n\n#","ref":"examples.html#simple-sky-theme"},{"type":"extras","title":"Light theme - Examples","doc":"``` elixir\ndata\n|> SparklineSvg.new(width: 200, height: 30, smoothing: 0, padding: 0)\n|> SparklineSvg.show_line(color: \"rgba(14, 165, 233, 0.5)\", width: 0.4)\n|> SparklineSvg.show_area(color: \"rgba(14, 165, 233, 0.2)\")\n|> SparklineSvg.add_marker(marker)\n|> SparklineSvg.add_marker(marker_area)\n|> SparklineSvg.to_svg!()\n```\n\n \n      \n \n\n#","ref":"examples.html#light-theme"},{"type":"extras","title":"Dark theme - Examples","doc":"``` elixir\ndata\n|> SparklineSvg.new(width: 200, height: 30, smoothing: 0, padding: 0)\n|> SparklineSvg.show_line(color: \"rgba(18, 181, 255, 0.8)\", width: 0.4)\n|> SparklineSvg.show_area(color: \"rgba(18, 181, 255, 0.4)\")\n|> SparklineSvg.add_marker(marker)\n|> SparklineSvg.add_marker(marker_area)\n|> SparklineSvg.to_svg!()\n```\n\n \n      \n \n\n<!-- tabs-close -->","ref":"examples.html#dark-theme"},{"type":"extras","title":"Simple purple theme - Examples","doc":"<!-- tabs-open -->\n\n#","ref":"examples.html#simple-purple-theme"},{"type":"extras","title":"Light theme - Examples","doc":"``` elixir\ndata\n|> SparklineSvg.new(width: 200, height: 30, smoothing: 0, padding: 0)\n|> SparklineSvg.show_line(color: \"rgba(168, 85, 247, 0.5)\", width: 0.4)\n|> SparklineSvg.show_area(color: \"rgba(168, 85, 247, 0.2)\")\n|> SparklineSvg.add_marker(marker)\n|> SparklineSvg.add_marker(marker_area)\n|> SparklineSvg.to_svg!()\n```\n\n \n      \n \n\n#","ref":"examples.html#light-theme"},{"type":"extras","title":"Dark theme - Examples","doc":"``` elixir\ndata\n|> SparklineSvg.new(width: 200, height: 30, smoothing: 0, padding: 0)\n|> SparklineSvg.show_line(color: \"rgba(173, 98, 255, 0.8)\", width: 0.4)\n|> SparklineSvg.show_area(color: \"rgba(173, 98, 255, 0.4)\")\n|> SparklineSvg.add_marker(marker)\n|> SparklineSvg.add_marker(marker_area)\n|> SparklineSvg.to_svg!()\n```\n\n \n      \n \n\n<!-- tabs-close -->","ref":"examples.html#dark-theme"},{"type":"extras","title":"Simple rose theme - Examples","doc":"<!-- tabs-open -->\n\n#","ref":"examples.html#simple-rose-theme"},{"type":"extras","title":"Light theme - Examples","doc":"``` elixir\ndata\n|> SparklineSvg.new(width: 200, height: 30, smoothing: 0, padding: 0)\n|> SparklineSvg.show_line(color: \"rgba(244, 63, 94, 0.5)\", width: 0.4)\n|> SparklineSvg.show_area(color: \"rgba(244, 63, 94, 0.2)\")\n|> SparklineSvg.add_marker(marker)\n|> SparklineSvg.add_marker(marker_area)\n|> SparklineSvg.to_svg!()\n```\n\n \n      \n \n\n#","ref":"examples.html#light-theme"},{"type":"extras","title":"Dark theme - Examples","doc":"``` elixir\ndata\n|> SparklineSvg.new(width: 200, height: 30, smoothing: 0, padding: 0)\n|> SparklineSvg.show_line(color: \"rgba(255, 83, 112, 0.8)\", width: 0.4)\n|> SparklineSvg.show_area(color: \"rgba(255, 83, 112, 0.4)\")\n|> SparklineSvg.add_marker(marker)\n|> SparklineSvg.add_marker(marker_area)\n|> SparklineSvg.to_svg!()\n```\n\n \n      \n \n\n<!-- tabs-close -->","ref":"examples.html#dark-theme"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.2.0 (2024-02-21) - Changelog","doc":"* Enhancements\n    * Support `:max` reference line\n    * Support `:min` reference line\n    * Support `:avg` reference line\n    * Support `:median` reference line\n    * Support `:dasharray` option for lines, markers, and reference lines","ref":"changelog.html#v0-2-0-2024-02-21"},{"type":"extras","title":"v0.1.1 (2024-02-12) - Changelog","doc":"* Bug fixes\n    * Fix typespec of `t:SparklineSvg.marker/0` and `t:SparklineSvg.markers/0`","ref":"changelog.html#v0-1-1-2024-02-12"},{"type":"extras","title":"v0.1.0 (2024-02-11) - Changelog","doc":"* Enhancements\n    * First public release\n    * Support line, dots, and area\n    * Support markers","ref":"changelog.html#v0-1-0-2024-02-11"},{"type":"extras","title":"License","doc":"Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\n   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n   1. Definitions.\n\n      \"License\" shall mean the terms and conditions for use, reproduction,\n      and distribution as defined by Sections 1 through 9 of this document.\n\n      \"Licensor\" shall mean the copyright owner or entity authorized by\n      the copyright owner that is granting the License.\n\n      \"Legal Entity\" shall mean the union of the acting entity and all\n      other entities that control, are controlled by, or are under common\n      control with that entity. For the purposes of this definition,\n      \"control\" means (i) the power, direct or indirect, to cause the\n      direction or management of such entity, whether by contract or\n      otherwise, or (ii) ownership of fifty percent (50%) or more of the\n      outstanding shares, or (iii) beneficial ownership of such entity.\n\n      \"You\" (or \"Your\") shall mean an individual or Legal Entity\n      exercising permissions granted by this License.\n\n      \"Source\" form shall mean the preferred form for making modifications,\n      including but not limited to software source code, documentation\n      source, and configuration files.\n\n      \"Object\" form shall mean any form resulting from mechanical\n      transformation or translation of a Source form, including but\n      not limited to compiled object code, generated documentation,\n      and conversions to other media types.\n\n      \"Work\" shall mean the work of authorship, whether in Source or\n      Object form, made available under the License, as indicated by a\n      copyright notice that is included in or attached to the work\n      (an example is provided in the Appendix below).\n\n      \"Derivative Works\" shall mean any work, whether in Source or Object\n      form, that is based on (or derived from) the Work and for which the\n      editorial revisions, annotations, elaborations, or other modifications\n      represent, as a whole, an original work of authorship. For the purposes\n      of this License, Derivative Works shall not include works that remain\n      separable from, or merely link (or bind by name) to the interfaces of,\n      the Work and Derivative Works thereof.\n\n      \"Contribution\" shall mean any work of authorship, including\n      the original version of the Work and any modifications or additions\n      to that Work or Derivative Works thereof, that is intentionally\n      submitted to Licensor for inclusion in the Work by the copyright owner\n      or by an individual or Legal Entity authorized to submit on behalf of\n      the copyright owner. For the purposes of this definition, \"submitted\"\n      means any form of electronic, verbal, or written communication sent\n      to the Licensor or its representatives, including but not limited to\n      communication on electronic mailing lists, source code control systems,\n      and issue tracking systems that are managed by, or on behalf of, the\n      Licensor for the purpose of discussing and improving the Work, but\n      excluding communication that is conspicuously marked or otherwise\n      designated in writing by the copyright owner as \"Not a Contribution.\"\n\n      \"Contributor\" shall mean Licensor and any individual or Legal Entity\n      on behalf of whom a Contribution has been received by Licensor and\n      subsequently incorporated within the Work.\n\n   2. Grant of Copyright License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      copyright license to reproduce, prepare Derivative Works of,\n      publicly display, publicly perform, sublicense, and distribute the\n      Work and such Derivative Works in Source or Object form.\n\n   3. Grant of Patent License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      (except as stated in this section) patent license to make, have made,\n      use, offer to sell, sell, import, and otherwise transfer the Work,\n      where such license applies only to those patent claims licensable\n      by such Contributor that are necessarily infringed by their\n      Contribution(s) alone or by combination of their Contribution(s)\n      with the Work to which such Contribution(s) was submitted. If You\n      institute patent litigation against any entity (including a\n      cross-claim or counterclaim in a lawsuit) alleging that the Work\n      or a Contribution incorporated within the Work constitutes direct\n      or contributory patent infringement, then any patent licenses\n      granted to You under this License for that Work shall terminate\n      as of the date such litigation is filed.\n\n   4. Redistribution. You may reproduce and distribute copies of the\n      Work or Derivative Works thereof in any medium, with or without\n      modifications, and in Source or Object form, provided that You\n      meet the following conditions:\n\n      (a) You must give any other recipients of the Work or\n          Derivative Works a copy of this License; and\n\n      (b) You must cause any modified files to carry prominent notices\n          stating that You changed the files; and\n\n      (c) You must retain, in the Source form of any Derivative Works\n          that You distribute, all copyright, patent, trademark, and\n          attribution notices from the Source form of the Work,\n          excluding those notices that do not pertain to any part of\n          the Derivative Works; and\n\n      (d) If the Work includes a \"NOTICE\" text file as part of its\n          distribution, then any Derivative Works that You distribute must\n          include a readable copy of the attribution notices contained\n          within such NOTICE file, excluding those notices that do not\n          pertain to any part of the Derivative Works, in at least one\n          of the following places: within a NOTICE text file distributed\n          as part of the Derivative Works; within the Source form or\n          documentation, if provided along with the Derivative Works; or,\n          within a display generated by the Derivative Works, if and\n          wherever such third-party notices normally appear. The contents\n          of the NOTICE file are for informational purposes only and\n          do not modify the License. You may add Your own attribution\n          notices within Derivative Works that You distribute, alongside\n          or as an addendum to the NOTICE text from the Work, provided\n          that such additional attribution notices cannot be construed\n          as modifying the License.\n\n      You may add Your own copyright statement to Your modifications and\n      may provide additional or different license terms and conditions\n      for use, reproduction, or distribution of Your modifications, or\n      for any such Derivative Works as a whole, provided Your use,\n      reproduction, and distribution of the Work otherwise complies with\n      the conditions stated in this License.\n\n   5. Submission of Contributions. Unless You explicitly state otherwise,\n      any Contribution intentionally submitted for inclusion in the Work\n      by You to the Licensor shall be under the terms and conditions of\n      this License, without any additional terms or conditions.\n      Notwithstanding the above, nothing herein shall supersede or modify\n      the terms of any separate license agreement you may have executed\n      with Licensor regarding such Contributions.\n\n   6. Trademarks. This License does not grant permission to use the trade\n      names, trademarks, service marks, or product names of the Licensor,\n      except as required for reasonable and customary use in describing the\n      origin of the Work and reproducing the content of the NOTICE file.\n\n   7. Disclaimer of Warranty. Unless required by applicable law or\n      agreed to in writing, Licensor provides the Work (and each\n      Contributor provides its Contributions) on an \"AS IS\" BASIS,\n      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n      implied, including, without limitation, any warranties or conditions\n      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n      PARTICULAR PURPOSE. You are solely responsible for determining the\n      appropriateness of using or redistributing the Work and assume any\n      risks associated with Your exercise of permissions under this License.\n\n   8. Limitation of Liability. In no event and under no legal theory,\n      whether in tort (including negligence), contract, or otherwise,\n      unless required by applicable law (such as deliberate and grossly\n      negligent acts) or agreed to in writing, shall any Contributor be\n      liable to You for damages, including any direct, indirect, special,\n      incidental, or consequential damages of any character arising as a\n      result of this License or out of the use or inability to use the\n      Work (including but not limited to damages for loss of goodwill,\n      work stoppage, computer failure or malfunction, or any and all\n      other commercial damages or losses), even if such Contributor\n      has been advised of the possibility of such damages.\n\n   9. Accepting Warranty or Additional Liability. While redistributing\n      the Work or Derivative Works thereof, You may choose to offer,\n      and charge a fee for, acceptance of support, warranty, indemnity,\n      or other liability obligations and/or rights consistent with this\n      License. However, in accepting such obligations, You may act only\n      on Your own behalf and on Your sole responsibility, not on behalf\n      of any other Contributor, and only if You agree to indemnify,\n      defend, and hold each Contributor harmless for any liability\n      incurred by, or claims asserted against, such Contributor by reason\n      of your accepting any such warranty or additional liability.\n\n   END OF TERMS AND CONDITIONS\n\n   APPENDIX: How to apply the Apache License to your work.\n\n      To apply the Apache License to your work, attach the following\n      boilerplate notice, with the fields enclosed by brackets \"[]\"\n      replaced with your own identifying information. (Don't include\n      the brackets!)  The text should be enclosed in the appropriate\n      comment syntax for the file format. We also recommend that a\n      file or class name and description of purpose be included on the\n      same \"printed page\" as the copyright notice for easier\n      identification within third-party archives.\n\n   Copyright [2024] [Gil Clavien]\n\n   Licensed under the Apache License, Version 2.0 (the \"License\");\n   you may not use this file except in compliance with the License.\n   You may obtain a copy of the License at\n\n       http://www.apache.org/licenses/LICENSE-2.0\n\n   Unless required by applicable law or agreed to in writing, software\n   distributed under the License is distributed on an \"AS IS\" BASIS,\n   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n   See the License for the specific language governing permissions and\n   limitations under the License.","ref":"license.html"}],"content_type":"text/markdown"}